==> python-vertica_0.10.1.orig.tar.gz: vertica-python-0.10.1/vertica_python/vertica/messages/backend_messages/__init__.py <==
# Copyright (c) 2018-2019 Micro Focus or one of its affiliates.
# Copyright (c) 2018 Uber Technologies, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Copyright (c) 2013-2017 Uber Technologies, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from __future__ import print_function, division, absolute_import

from .authentication import Authentication
from .backend_key_data import BackendKeyData
from .bind_complete import BindComplete
from .close_complete import CloseComplete
from .command_complete import CommandComplete
from .command_description import CommandDescription
from .copy_in_response import CopyInResponse
from .data_row import DataRow
from .empty_query_response import EmptyQueryResponse
from .error_response import ErrorResponse
from .load_balance_response import LoadBalanceResponse
from .no_data import NoData
from .notice_response import NoticeResponse
from .parameter_description import ParameterDescription
from .parameter_status import ParameterStatus
from .parse_complete import ParseComplete
from .portal_suspended import PortalSuspended
from .ready_for_query import ReadyForQuery
from .row_description import RowDescription
from .unknown import Unknown

__all__ = ['RowDescription', 'ReadyForQuery', 'PortalSuspended', 'ParseComplete', 'ParameterStatus',
           'ParameterDescription', 'NoticeResponse', 'NoData', 'LoadBalanceResponse',
           'ErrorResponse', 'EmptyQueryResponse', 'DataRow', 'CopyInResponse', 'CommandDescription',
           'CommandComplete', 'CloseComplete', 'BindComplete', 'BackendKeyData', 'Authentication',
           'Unknown']

==> python-vertica_0.11.0.orig.tar.gz: vertica-python-0.11.0/vertica_python/vertica/messages/backend_messages/__init__.py <==
# Copyright (c) 2018-2020 Micro Focus or one of its affiliates.
# Copyright (c) 2018 Uber Technologies, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# Copyright (c) 2013-2017 Uber Technologies, Inc.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

from __future__ import print_function, division, absolute_import

from .authentication import Authentication
from .backend_key_data import BackendKeyData
from .bind_complete import BindComplete
from .close_complete import CloseComplete
from .command_complete import CommandComplete
from .command_description import CommandDescription
from .copy_done_response import CopyDoneResponse
from .copy_in_response import CopyInResponse
from .data_row import DataRow
from .empty_query_response import EmptyQueryResponse
from .end_of_batch_response import EndOfBatchResponse
from .error_response import ErrorResponse
from .load_balance_response import LoadBalanceResponse
from .load_file import LoadFile
from .no_data import NoData
from .notice_response import NoticeResponse
from .parameter_description import ParameterDescription
from .parameter_status import ParameterStatus
from .parse_complete import ParseComplete
from .portal_suspended import PortalSuspended
from .ready_for_query import ReadyForQuery
from .row_description import RowDescription
from .unknown import Unknown
from .verify_files import VerifyFiles
from .write_file import WriteFile

__all__ = ['Authentication', 'BackendKeyData', 'BindComplete', 'CloseComplete',
           'CommandComplete', 'CommandDescription', 'CopyDoneResponse', 'CopyInResponse', 'DataRow',
           'EmptyQueryResponse', 'EndOfBatchResponse', 'ErrorResponse', 'LoadBalanceResponse',
           'LoadFile', 'NoData', 'NoticeResponse', 'ParameterDescription', 'ParameterStatus',
           'ParseComplete', 'PortalSuspended', 'ReadyForQuery', 'RowDescription',
           'Unknown', 'VerifyFiles', 'WriteFile']
